from setuptools import find_packages, setup

setup(
    name='logt',
    packages=find_packages(include=['logt']),
    version='0.1.0',
    description='logt launching soon',
    author='Soham Chakraborty',
    license='AGPLv3',
    install_requires=[],
)
